@@ -1,8 +1,8 @@
 #ifndef S7_H
 #define S7_H
 
-#define S7_VERSION "9.5"
-#define S7_DATE "2020-8-3"
+#define S7_VERSION "9.6"
+#define S7_DATE "14-10-2020"
 
 #include <stdint.h>           /* for int64_t */
 
@@ -34,6 +34,7 @@ s7_scheme *s7_init(void);
    * s7_pointer is a Scheme object of any (Scheme) type
    * s7_init creates the interpreter.
    */
+void s7_free(s7_scheme *sc);
 
 typedef s7_pointer (*s7_function)(s7_scheme *sc, s7_pointer args);   /* that is, obj = func(s7, args) -- args is a list of arguments */
 
@@ -216,6 +217,7 @@ s7_pointer s7_cddaar(s7_pointer p);
 bool s7_is_list(s7_scheme *sc, s7_pointer p);                                /* (list? p) -> (or (pair? p) (null? p)) */
 bool s7_is_proper_list(s7_scheme *sc, s7_pointer p);                         /* (proper-list? p) */
 s7_int s7_list_length(s7_scheme *sc, s7_pointer a);                          /* (length a) */
+s7_pointer s7_make_list(s7_scheme *sc, s7_int len, s7_pointer init);         /* (make-list len init) */
 s7_pointer s7_list(s7_scheme *sc, s7_int num_values, ...);                   /* (list ...) */
 s7_pointer s7_list_nl(s7_scheme *sc, s7_int num_values, ...);                /* (list ...) arglist should be NULL terminated (more error checks than s7_list) */
 s7_pointer s7_reverse(s7_scheme *sc, s7_pointer a);                          /* (reverse a) */
@@ -884,6 +886,8 @@ typedef s7_double s7_Double;
  * 
  *        s7 changes
  *
+ * 10-Sep:    s7_free.
+ * 5-Aug:     s7_make_list.
  * 31-July:   add s7_define_constant_with_environment and s7_dilambda_with_environment.
  * 29-July:   open-input|output-function. add S7_NUM_READ_CHOICES to s7_read_t enum and remove (unused) S7_READ_BYTE.
  * 20-July:   s7_c_pointer_with_type. notcurses_s7.c and nrepl.scm. *autoload-hook*. 
