@@ -10,6 +10,8 @@
 (define (no-set s v)
   (error 'bad "can't set ~S" s))
 
+(immutable! quote)
+
 (for-each (lambda (x)
 	    (when (syntax? (symbol->value x))
 	      (set! (setter x) no-set)
@@ -72,6 +74,8 @@
 (load "stuff.scm")
 ;(load "write.scm")
 (load "mockery.scm")
+(load "case.scm")
+(define match?  ((funclet 'case*) 'case*-match?))
 
 (define mock-number (*mock-number* 'mock-number))
 (define mock-pair (*mock-pair* 'mock-pair))
@@ -264,7 +268,7 @@
 ;(define (checked-let-set! . args) (apply let-set! (curlet) args))
 ;(define (checked-varlet . args) (apply varlet (sublet (curlet)) args))
 ;(define (checked-cutlet . args) (apply cutlet (sublet (curlet)) args))
-(define (checked-procedure-source . args) (copy (apply procedure-source args) :readable))
+(define (checked-procedure-source . args) (copy (procedure-source (car args)) :readable))
 
 (load "s7test-block.so" (sublet (curlet) (cons 'init_func 'block_init)))
 
@@ -312,11 +316,13 @@
 (define-expansion (_ft2_ . args)
   `(let () (define (_f_) ,@args) (define (g) (_f_)) (g) (g)))
 
+(define (_rf11_ i x) (if (> i 0) (_rf11_ (- i 1) x) (x)))
 (define-expansion (_rf1_ . args)
-  `(let ((y 0)) (define (_rf11_ i x) (if (> i 0) (_rf11_ (- i 1) x) (x))) (_rf11_ 1 (lambda () ,@args))))
+  `(let ((y 0)) (_rf11_ 1 (lambda () ,@args))))
 
+(define (_rf22_ i x) (if (> i 0) (_rf22_ (- i 1) x) (x i)))
 (define-expansion (_rf2_ . args) 
-  `(let () (define (_rf22_ i x) (if (> i 0) (_rf22_ (- i 1) x) (x i))) (_rf22_ 1 (lambda (y) (begin ,@args)))))
+  `(let () (_rf22_ 1 (lambda (y) (begin ,@args)))))
 
 (define-expansion (_do1_ . args)
   `(with-output-to-string 
@@ -566,6 +572,7 @@
 ;(define* (make-string len (char #\space)) (#_make-string len char))
 ;(define* (make-byte-vector len (byte 0)) (#_make-byte-vector len byte))
 (define with-bignums (provided? 'bignums))
+(define (boolean|integer? x) (or (boolean? x) (integer? x)))
 
 (let ((functions (vector 'not '= '+ 'cdr 'real? 'rational? 'number? '> '- 'integer? 'apply 'subvector? 'subvector-position 'subvector-vector
 			  'abs '* 'null? 'imag-part '/ 'vector-set! 'equal? 'magnitude 'real-part 'pair? 'max 'nan? 'string->number 'list
@@ -625,10 +632,12 @@
 
 			  'open-input-string 'open-output-string 
 			  'open-input-file 
+			  'open-input-function 'open-output-function
 			  'define
 			  'newline
 			  'random-state 
 			  'gensym
+			  'case*
 			  'if 'begin 'cond 'case 'or 'and 'do 'with-let 'with-baffle 'when 'unless 'let-temporarily
 			  'byte-vector-set! ; 'make-byte-vector 
 			  'write-char 'call/cc 'write-byte 'write-string 
@@ -673,7 +682,7 @@
 			  ;'reader-cond ;-- cond test clause can involve unbound vars: (null? i) for example
 			  ;'funclet
 			  ;'random 
-			  ;'quote
+			  'quote
 			  '*error-hook*
 			  ;'cond-expand 
 			  ;'random-state->list 
@@ -780,6 +789,7 @@
 			  ;'pp
 			  'kar '_dilambda_ '_vals_ '_vals1_ '_vals2_
 			  'free1 'free2 'free3
+			  ;'match?
 			  'catch 'length 'eq? 'car '< 'assq 'complex? 'vector-ref 
 			  
 			  ;'*function*
@@ -790,24 +800,49 @@
 		    "3441313796169221281/1720656898084610641" "1855077841/1311738121" "4478554083/3166815962" "20057446674355970889/10028723337177985444"
 		    "(cosh 128)" "(cosh (bignum 128.0))" "(bignum -1/2)" "123456789.123456789" "(bignum 1234)" "(bignum 1234.1234)" "(bignum 1+i)"
 		    "(bignum +inf.0)" "(bignum +nan.0)" "(bignum -inf.0)" "(bignum 0+i)" "(bignum 0.0)" "(bignum 0-i)"
-
-		    "(if (> (random 1.0) 0.5) 123 (bignum 123))"
-		    "(if (> (random 1.0) 0.5) 1/3 (bignum 1/3))"
-		    "(if (> (random 1.0) 0.5) 2.0 (bignum 2.0))"
-		    "(if (> (random 1.0) 0.5) 1+i (bignum 1+i))"
-		    "(if (> (random 1.0) 0.5) 8796093022208 (bignum 8796093022208))"
-		    "(if (> (random 1.0) 0.5) 1855077841/1311738121 (bignum 1855077841/1311738121))"
-		    "(if (> (random 1.0) 0.5) 1.0e18 (bignum 1.0e18))"
-		    "(if (> (random 1.0) 0.5) +inf.0 (bignum +inf.0))"
-		    "(if (> (random 1.0) 0.5) +nan.0 (bignum +nan.0))"
-		    "(if (> (random 1.0) 0.5) 0+0/0i (bignum 0+0/0i))"
-		    "(if (> (random 1.0) 0.5) 0/0+0/0i (bignum 0/0+0/0i))"
-		    "(if (> (random 1.0) 0.5) 9223372036854775806 (bignum 9223372036854775806))"
-		    "(if (> (random 1.0) 0.5) (vector 123) (vector (bignum 123)))"
+#|
+		    ;(reader-cond ((provided? 'gmp)
+				  "(if (> (random 1.0) 0.5) -123 (bignum -123))"
+				  "(if (> (random 1.0) 0.5) 1/3 (bignum 1/3))"
+				  "(if (> (random 1.0) 0.5) -2.0 (bignum -2.0))"
+				  "(if (> (random 1.0) 0.5) 1+i (bignum 1+i))"
+				  "(if (> (random 1.0) 0.5) 8796093022208 (bignum 8796093022208))"
+				  "(if (> (random 1.0) 0.5) 1855077841/1311738121 (bignum 1855077841/1311738121))"
+				  "(if (> (random 1.0) 0.5) 1.0e18 (bignum 1.0e18))"
+				  "(if (> (random 1.0) 0.5) +inf.0 (bignum +inf.0))"
+				  "(if (> (random 1.0) 0.5) +nan.0 (bignum +nan.0))"
+				  "(if (> (random 1.0) 0.5) 0+0/0i (bignum 0+0/0i))"
+				  "(if (> (random 1.0) 0.5) 0/0+0/0i (bignum 0/0+0/0i))"
+				  "(if (> (random 1.0) 0.5) 9223372036854775806 (bignum 9223372036854775806))"
+				  "(if (> (random 1.0) 0.5) (vector 123) (vector (bignum 123)))"
+				  "(if (> (random 1.0) 0.5) 2.5 (bignum 2.5))"
+				  "(if (> (random 1.0) 0.5) 1.5 (bignum 1.5))"
+				  "(if (> (random 1.0) 0.5) 5/2 (bignum 5/2))"
+				  "(if (> (random 1.0) 0.5) 3/2 (bignum 3/2))"
+				  
+				  "18446744073709551614"
+				  "18446744073709551614/3"
+				  "18446744073709551615.0"
+				  "18446744073709551614+i"
+				  "-18446744073709551616"
+				  "-18446744073709551616/3"
+				  "-18446744073709551617.0"
+				  "-18446744073709551616-18446744073709551614i"
+				  "9223372036854775807"
+				  "-9223372036854775807"
+				  "9007199254740992"
+				  "9223372036854775800.1"
+				  "-9223372036854775800.1+i"
+				  "92233720368547758/19"
+				  "92233720368547758/5"
+				  "-4611686018427387905"
+				  "4611686018427387904"
+				  ;))
+|#
 
 		    "\"ho\"" ":ho" "'ho" "(list 1)" "(list 1 2)" "(cons 1 2)" "'()" "(list (list 1 2))" "(list (list 1))" "(list ())" "=>" 
 		    "#f" "#t" "()" "#()" "\"\"" "'#()" ; ":write" -- not this because sr2 calls write and this can be an arg to sublet redefining write
-		    ":readable" ":rest" ":allow-other-keys" ":a" 
+		    ":readable" ":rest" ":allow-other-keys" ":a"
 		    "1/0+i" "0+0/0i" "0+1/0i" "1+0/0i" "0/0+0/0i" "0/0+i" "+nan.0-3i" "+inf.0-nan.0i"
 		    "cons" "''2" "\"ra\"" 
 		    "#\\a" "#\\A" "\"str1\"" "\"STR1\"" "#\\0" "0+." ".0-"
@@ -826,7 +861,7 @@
 		    "(define-macro (_m1_ a) `(+ ,a 1))" "(define-bacro (_b1_ a) `(* ,a 2))"
 		    "(macro (a) `(+ ,a 1))" "(bacro (a) `(* ,a 2))" "(macro* (a (b 1)) `(+ ,a ,b))" "(bacro* (a (b 2)) `(* ,a ,b))"
 		    "(string #\\c #\\null #\\b)" "#2d((100 200) (3 4))" "#r(0 1)" "#i2d((101 201) (3 4))" "#r2d((.1 .2) (.3 .4))" "#i1d(15 25)"
-		    "(values 1 2)" "(values)" "(values #\\c 3 1.2)" "(values \"ho\")" "(values 1 2 3 4 5 6 7 8 9 10)"
+		    "(values 1 2)" "(values)" "(values #\\c 3 1.2)" "(values \"ho\")" "(values 1 2 3 4 5 6 7 8 9 10)" "(values (define b1 3))"
 		    "`(x)" "`(+ x 1)" "`(x 1)" "`((x))" "`((+ x 1))" "`(((+ x 1)))" "`((set! x (+ x 1)) (* x 2))" "`((x 1))" "`(((x 1))) "
 		    "`(x . 1)" "`((x . 1))" "`(1)" "`((1))" "`((1) . x)" ;; "'(- 1)" 
 		    "(+ i 1)" "(pi)"
@@ -855,16 +890,30 @@
                                             (let ((res (list (caar lst) (cdar lst))))
                                               (set! lst (cdr lst)) res)
                                             #<eof>))))"
+		    "(display (call/cc (lambda (return)
+					(let ((val \"line 1~%line 2~%line 3\"))
+					  (call-with-input-string val
+					    (lambda (p) (return 'oops)))))))"
+		    "(display (call-with-exit (lambda (return)
+					(let ((val \"line 1~%line 2~%line 3\"))
+					  (with-input-from-string val
+					    (lambda (p) (return 'oops)))))))"
+		    "(display (call/cc (lambda (return)
+					  (call-with-output-string
+					    (lambda (p) (return 'oops))))))"
 
-		    "#<eof>" "#<undefined>" "#<unspecified>" "#unknown" "___lst" "#<bignum: 3>"
+		    "#<eof>" "#<undefined>" "#<unspecified>" "#unknown" "___lst" "#<bignum: 3>" 
+		    "#<>" "#label:>" "#<...>"
 		    "#o123" "#b101" "#\\newline" "#\\alarm" "#\\delete" "#_cons" "#x123.123" "#\\x65" ;"_1234_" "kar" "#_+"
 		    "(provide 'pizza)" "(require pizza)"
 		    
 		    "(call-with-exit (lambda (goto) goto))"
-		    ;;"(with-baffle (call/cc (lambda (cc) cc)))"
+		    "(with-baffle (call/cc (lambda (cc) (cc 1))))"
 		    "(symbol->string 'x)" "(symbol \"a b\")" "(symbol \"(\\\")\")"
+		    "(call-with-exit (lambda (return) (return 'ce)))"
 		    "(call-with-exit (lambda (return) (let ((x 1) (y 2)) (return x y))))"
-		    ;;"(call/cc (lambda (return) (let ((x 1) (y 2)) (return x y))))"
+		    "(call/cc (lambda (return) (return 'oops)))"
+		    "(call/cc (lambda (return) (let ((x 1) (y 2)) (return x y))))"
 		    "(let ((x 1)) (dynamic-wind (lambda () (set! x 2)) (lambda () (+ x 1)) (lambda () (set! x 1))))"
 
 		    "(let-temporarily ((x 1)) (free1))" "(let-temporarily ((x #(1)) (i 0)) (free2))" "(let-temporarily ((local-func (lambda (x) x))) (free3))"
@@ -895,7 +944,7 @@
 
 		    "(make-hash-table 8 eq? (cons symbol? integer?))"
 		    "(make-hash-table 8 equivalent? (cons symbol? #t))"
-		    ;"(let ((a 1)) (set! (setter 'a) integer?) (curlet))"
+		    "(let ((a 1)) (set! (setter 'a) integer?) (curlet))"
 		    ;"(let () (define-constant a 1) (curlet))"
 
 		    "bigi0" "bigi1" "bigi2" "bigrat" "bigflt" "bigcmp" "bigf2"
@@ -913,7 +962,7 @@
 		    "'value"
 
 		    " #| a comment |# "
-		    "(subvector (vector 0 1 2 3 4) 0 3)" "(substring \"0123\" 2)"
+		    "(subvector 0 3 (vector 0 1 2 3 4))" "(substring \"0123\" 2)"
 		    "(vector-dimensions (block))" 
 		    "(append (block) (block))"
 		    "(let-temporarily ((x 1234)) (+ x 1))"
@@ -921,8 +970,7 @@
 
 		    ;;"(catch #t 1 (lambda (a b) b))" "(catch #t (lambda () (fill! (rootlet) 1)) (lambda (type info) info))"
 
-		    "#xfeedback" "#_asdf"
-		    ;"quote" "'"
+		    "quote" "when" ;"'" "(quote)" "(quote . 1)" "(when)" "(when . 1)"
 		    ;"if" ; causes stack overflow when used as lambda arg name and (()... loop)
 		    "begin" "cond" "case" "when" "unless" "letrec" "letrec*" "or" "and" "let-temporarily"
 		    ;;"lambda*" "lambda" ;-- cyclic body etc
@@ -960,7 +1008,7 @@
 		    "(make-hash-table 8 #f (cons symbol? block?))"
 		    "(let ((i 32)) (set! (setter 'i) integer?) (curlet))"
 
-		    "(let () (define (boolean|integer? x) (or (boolean? x) (integer? x))) (make-vector 3 #f boolean|integer?)))"
+		    "(make-vector 3 #f boolean|integer?)"
 
 		    "(immutable! #(1 2))" "(immutable! #r(1 2))" "(immutable! \"asdf\")" "(immutable! '(1 2))" "(immutable! (hash-table 'a 1))"
 		    ;"(lambda (x) (fill! x 0))"
@@ -985,7 +1033,7 @@
 		    "(let ((<1> (vector #f #f #f))) (set! (<1> 0) <1>) (set! (<1> 1) <1>) (set! (<1> 2) <1>) <1>)"
 		    "#i3d(((1 2 3) (3 4 5)) ((5 6 1) (7 8 2)))"
 		    "(hash-table +nan.0 1)" "#\\7" "(inlet :a (hash-table 'b 1))" "(openlet (immutable! (inlet :a 1)))"
-		    "(subvector #i2d((1 2) (3 4)) 0 4)" "(subvector #i2d((1 2) (3 4)) 0 4 '(4))" "(subvector #i2d((1 2) (3 4)) 1 3 '(2 1))"
+		    "(subvector #i2d((1 2) (3 4)))" "(subvector #i2d((1 2) (3 4)) 0 4 '(4))" "(subvector #i2d((1 2) (3 4)) 1 3 '(2 1))"
 
 		    #f #f #f
 		    ))
@@ -1049,11 +1097,12 @@
 	      (list "(begin (_cat1_ " "(begin (_cat2_ ")
 	      (list "(begin (let ((+ -)) " "(begin (let () (define + -) ")
 	      (list "(let ((+ -)) (let ((cons list)) " "(let ((cons list)) (let ((+ -)) ")
-	      (list "(begin (#_vector " "(begin ((with-let (unlet) vector) ")
+	      ;(list "(begin (#_vector " "(begin ((with-let (unlet) vector) ")
 	      (list "(let-temporarily (((*s7* 'print-length) 3)) (begin " "(let-temporarily (((*s7* 'print-length) 3)) (begin ")
 	      ))
       
-      (chars (vector #\( #\( #\) #\space))) ; #\/ #\# #\, #\` #\@ #\. #\:))  ; #\\ #\> #\space))
+      (chars (vector #\( #\( #\) #\space))) ; #\' #\/ #\# #\, #\` #\@ #\. #\:))  ; #\\ #\> #\space))
+
   (let ((clen (length chars))
 	(flen (length functions))
 	(alen (length args))
@@ -1089,7 +1138,7 @@
       (let ((parens 1)
 	    (dqs 0)
 	    (j 1)
-	    (str (make-string 8192 #\space)))
+	    (str (make-string 4096 #\space)))
 	(lambda (size)
 	  (set! parens 1)
 	  (set! dqs 0)
@@ -1097,13 +1146,9 @@
 	  (fill! str #\space)
 	  (set! (str 0) #\()
 
-	  (let ((opstr (fix-op (functions (random flen)))))
-	    (do ((oplen (length opstr))
-		 (n 0 (+ n 1))
-		 (k j (+ k 1)))
-		((= n oplen) 
-		 (set! j k))
-	      (string-set! str k (string-ref opstr n))))
+          (let ((opstr (fix-op (functions (random flen)))))
+            (string-copy opstr str j)
+            (set! j (+ j (length opstr))))
 	  
 	  (set! (str j) #\space)
 	  (set! j (+ j 1))
@@ -1122,14 +1167,10 @@
 		(case (str j)
 		  ((#\()
 		   (set! parens (+ parens 1))
-		   (let ((opstr (fix-op (functions (random flen)))))
-		     (do ((oplen (length opstr))
-			  (n 0 (+ n 1))
-			  (k (+ j 1) (+ k 1)))
-			 ((= n oplen) 
-			  (set! j k))
-		       (string-set! str k (string-ref opstr n))))
-		   (set! j (+ j 1))
+
+                   (let ((opstr (fix-op (functions (random flen)))))
+                     (string-copy opstr str (+ j 1))
+                     (set! j (+ j 1 (length opstr))))
 		   (set! (str j) #\space))
 		  
 		  ((#\))
@@ -1142,14 +1183,11 @@
 		   (let ((nargs (random args-ran)))
 		     (do ((n 0 (+ n 1)))
 			 ((= n nargs))
-		       (let ((argstr (get-arg)))
-			 (do ((arglen (length argstr))
-			      (n 0 (+ n 1))
-			      (k (+ j 1) (+ k 1)))
-			     ((= n arglen)
-			      (set! j k))
-			   (string-set! str k (string-ref argstr n))))
-		       (set! j (+ j 1))
+
+                       (let ((argstr (get-arg)))
+                         (string-copy argstr str (+ j 1))
+                         (set! j (+ j (length argstr) 1)))
+		       ;(set! j (+ j 1))
 		       (set! (str j) #\space))))
 		  
 		  ((#\")
@@ -1160,7 +1198,8 @@
 	  (if (= dqs 1)
 	      (begin
 		(set! (str j) #\")
-		(set! j (+ j 1))))
+		;(set! j (+ j 1))
+		))
 	  
 	  (if (> parens 0)
 	      (do ((k parens (- k 1))
@@ -1169,19 +1208,31 @@
 		   (set! j n))
 		(string-set! str n #\))))
 	  
-					;(format #t "~A~%" (substring str 0 j))
+	  ;(format *stderr* "~A~%" (substring str 0 j))
 	  (substring str 0 j))))
 
+    (define (type-eqv? v1 v2 v3 v4)
+      (let ((v1-type (type-of v1)))
+	(and (or (eq? v1-type (type-of v2)) (and (number? v1) (number? v2) (= v1 v2)))
+	     (or (eq? v1-type (type-of v3)) (and (number? v1) (number? v3) (= v1 v3)))
+	     (or (eq? v1-type (type-of v4)) (and (number? v1) (number? v4) (= v1 v4))))))
+
     (define (same-type? val1 val2 val3 val4 str str1 str2 str3 str4)
-      (cond ((not (and (eq? (type-of val1) (type-of val2))
-		       (eq? (type-of val1) (type-of val3))
-		       (eq? (type-of val1) (type-of val4))))
-	     (unless (or (eq? error-type 'baffled!) ; _rd3_ vs _rd4_ for example where one uses dynamic-wind which has built-in baffles
-			 (nan? val1)
+      (cond ((not (type-eqv? val1 val2 val3 val4))
+	     (unless (or (memq error-type '(out-of-range wrong-type-arg baffled!)) ; _rd3_ vs _rd4_ for example where one uses dynamic-wind which has built-in baffles
+			 (and (number? val1)
+			      (or (nan? val1)
+				  (infinite? val1)
+				  (and (equivalent? val1 val2) 
+				       (equivalent? val1 val3) 
+				       (equivalent? val1 val4))))
+			 (equal? val1 "0")
 			 (string-position "set! _definee_" str)
 			 (and (iterator? _definee_) 
 			      (string-position "_definee_" str)))
-	       (when (string-position "_definee_" str) (format *stderr* "_definee_: ~W" old-definee))
+	       (when (string-position "_definee_" str) (format *stderr* "_definee_: ~W~%" old-definee))
+	       (when (string-position "bigrat" str) (format *stderr* "bigrat: ~W" bigrat))
+	       (when (string-position "-inf.0" str) (format *stderr* "-inf.0: ~W" -inf.0))
 		 (format *stderr* "~%~%~S~%~S~%~S~%~S~%    ~A~%    ~A~%    ~A~%    ~A~%" 
 			 str1 str2 str3 str4 
 			 (tp val1) (tp val2) (tp val3) (tp val4))
@@ -1206,7 +1257,7 @@
 		 (unless (and (eq? val1 val2)
 			      (eq? val1 val3)
 			      (eq? val1 val4))
-		   (when (string-position "_definee_" str) (format *stderr* "_definee_: ~W" old-definee))
+		   (when (string-position "_definee_" str) (format *stderr* "_definee_: ~W~%" old-definee))
 		   (format *stderr* "~%~%~S~%~S~%~S~%~S~%~S~%   ~A ~A ~A ~A~%" 
 			   str str1 str2 str3 str4 
 			   (tp val1) (tp val2) (tp val3) (tp val4))
@@ -1224,10 +1275,12 @@
 			   (and (eqv? len1 (length val2))
 				(eqv? len1 (length val3))
 				(eqv? len1 (length val4)))
+			   (and (string? val1)
+				(string->number val1))
 			   (string-position "set! _definee_" str) 
 			   (and (iterator? _definee_) 
 				(string-position "_definee_" str)))
-		 (when (string-position "_definee_" str) (format *stderr* "_definee_: ~W" old-definee))
+		 (when (string-position "_definee_" str) (format *stderr* "_definee_: ~W~%" old-definee))
 		 (format *stderr* "~%~%~S~%~S~%~S~%~S~%~S~%    ~A~%    ~A~%    ~A~%    ~A~%~%" 
 			 str str1 str2 str3 str4 
 			 (tp val1) (tp val2) (tp val3) (tp val4)))))
@@ -1239,7 +1292,9 @@
 			  (not (and (infinite? val2) (infinite? val3) (infinite? val4))))
 		     (and (finite? val1)
 			  (not (and (finite? val2) (finite? val3) (finite? val4))))
-		     (and (real? val1) (real? val2) (real? val3) (real? val4) 
+		     (and (not (= val1 val2))
+			  (not (zero? val1))
+			  (finite? val1) (real? val1) (real? val2) (real? val3) (real? val4) 
 			  (or (and (negative? val1) (or (positive? val2) (positive? val3) (positive? val4)))
 			      (and (positive? val1) (or (negative? val2) (negative? val3) (negative? val4))))))
 		 (format *stderr* "~%~%~S~%~S~%~S~%~S~%~S~%    ~A~%    ~A~%    ~A~%    ~A~%~%" 
@@ -1251,15 +1306,16 @@
 		 (unspecified? val1)
 		 (char? val1)
 		 (memq val1 '(#<eof> ())))
-	     (unless (and (eq? val1 val2)
-			  (eq? val1 val3)
-			  (eq? val1 val4))
-	       (unless (or (string-position "set! _definee_" str) 
-			   (and (iterator? _definee_) (string-position "_definee_" str)))
-		 (when (string-position "_definee_" str) (format *stderr* "_definee_: ~W" old-definee))
-		 (format *stderr* "~%~%~S~%~S~%~S~%~S~%~S~%   ~A ~A ~A ~A~%" 
-			 str str1 str2 str3 str4 
-			 (tp val1) (tp val2) (tp val3) (tp val4)))))
+	     (unless (or (and (eq? val1 val2)
+			      (eq? val1 val3)
+			      (eq? val1 val4))
+			 (string-position "set! _definee_" str) 
+			 (and (iterator? _definee_) 
+			      (string-position "_definee_" str)))
+	       (when (string-position "_definee_" str) (format *stderr* "_definee_: ~W~%" old-definee))
+	       (format *stderr* "~%~%~S~%~S~%~S~%~S~%~S~%   ~A ~A ~A ~A~%" 
+		       str str1 str2 str3 str4 
+		       (tp val1) (tp val2) (tp val3) (tp val4))))
 	    
 	    ((or (undefined? val1)
 		 (c-object? val1))
@@ -1306,6 +1362,7 @@
           'error)))
 
     (define (try-both str)
+      ;(format *stderr* "~A~%" str)
       (set! ostr str)
       (set! (current-output-port) #f)
 
@@ -1353,7 +1410,7 @@
     (define (test-it)
       (do ((m 0 (+ m 1))
 	   (n 0))
-	  ((= m 100000000) 
+	  ((= m 100000000)
 	   (format *stderr* "reached end of loop??~%"))
 	
 	(when (zero? (modulo m 100000))
@@ -1366,8 +1423,7 @@
 	))
 
     (catch #t
-      (lambda ()
-	(test-it))
+      test-it
       (lambda (type info)
 	(format *stderr* "~%~%outer: ~S ~S from ~S~%" type (apply format #f info) estr)
 	(format *stderr* "owlet: ~S~%" (owlet))))))
