@@ -310,4 +310,6 @@
   (test82)
   )
 
+(when (> (*s7* 'profile) 0)
+  (show-profile 200))
 (exit)
