@@ -142,4 +142,6 @@
   
 (testm)
 
+(when (> (*s7* 'profile) 0)
+  (show-profile 200))
 (#_exit)
